aboutsummaryrefslogtreecommitdiffstats
path: root/Software/Visual_Studio
diff options
context:
space:
mode:
authorRoy Ben-Shabat <Roy@Twine-s.com>2019-12-15 16:13:47 +0200
committerRoy Ben-Shabat <Roy@Twine-s.com>2019-12-15 16:13:47 +0200
commit24292197223caf2ffa1a771c38b2e2f7418ad03e (patch)
tree0c2733e1e27b219a188239c7d0ccfd252d20fd8b /Software/Visual_Studio
parent13c57f7ccabadd3ed75ffaef195d35c15c2a8c68 (diff)
downloadTango-24292197223caf2ffa1a771c38b2e2f7418ad03e.tar.gz
Tango-24292197223caf2ffa1a771c38b2e2f7418ad03e.zip
Added PowerDown and ThreadLoading to PMR.
Removed old ThreadLoading from PMR diagnostics.
Diffstat (limited to 'Software/Visual_Studio')
-rw-r--r--Software/Visual_Studio/Tango.PMR/Common/MessageType.cs24
-rw-r--r--Software/Visual_Studio/Tango.PMR/Diagnostics/StartThreadLoadingUpdateResponse.cs162
-rw-r--r--Software/Visual_Studio/Tango.PMR/Diagnostics/ThreadLoadingState.cs97
-rw-r--r--Software/Visual_Studio/Tango.PMR/Power/AbortPowerDownRequest.cs131
-rw-r--r--Software/Visual_Studio/Tango.PMR/Power/AbortPowerDownResponse.cs131
-rw-r--r--Software/Visual_Studio/Tango.PMR/Power/PowerDownState.cs48
-rw-r--r--Software/Visual_Studio/Tango.PMR/Power/StartPowerDownRequest.cs131
-rw-r--r--Software/Visual_Studio/Tango.PMR/Power/StartPowerDownResponse.cs217
-rw-r--r--Software/Visual_Studio/Tango.PMR/Tango.PMR.csproj5
-rw-r--r--Software/Visual_Studio/Tango.PMR/ThreadLoading/ContinueThreadLoadingRequest.cs168
-rw-r--r--Software/Visual_Studio/Tango.PMR/ThreadLoading/ContinueThreadLoadingResponse.cs132
-rw-r--r--Software/Visual_Studio/Tango.PMR/ThreadLoading/StartThreadLoadingRequest.cs (renamed from Software/Visual_Studio/Tango.PMR/Diagnostics/StartThreadLoadingUpdateRequest.cs)43
-rw-r--r--Software/Visual_Studio/Tango.PMR/ThreadLoading/StartThreadLoadingResponse.cs190
-rw-r--r--Software/Visual_Studio/Tango.PMR/ThreadLoading/ThreadLoadingState.cs53
14 files changed, 1245 insertions, 287 deletions
diff --git a/Software/Visual_Studio/Tango.PMR/Common/MessageType.cs b/Software/Visual_Studio/Tango.PMR/Common/MessageType.cs
index 38e58a257..77ebbef51 100644
--- a/Software/Visual_Studio/Tango.PMR/Common/MessageType.cs
+++ b/Software/Visual_Studio/Tango.PMR/Common/MessageType.cs
@@ -22,7 +22,7 @@ namespace Tango.PMR.Common {
static MessageTypeReflection() {
byte[] descriptorData = global::System.Convert.FromBase64String(
string.Concat(
- "ChFNZXNzYWdlVHlwZS5wcm90bxIQVGFuZ28uUE1SLkNvbW1vbiq2NAoLTWVz",
+ "ChFNZXNzYWdlVHlwZS5wcm90bxIQVGFuZ28uUE1SLkNvbW1vbiqwNgoLTWVz",
"c2FnZVR5cGUSCAoETm9uZRAAEhEKDUVycm9yUmVzcG9uc2UQARIUChBDYWxj",
"dWxhdGVSZXF1ZXN0EAMSFQoRQ2FsY3VsYXRlUmVzcG9uc2UQBBITCg9Qcm9n",
"cmVzc1JlcXVlc3QQBRIUChBQcm9ncmVzc1Jlc3BvbnNlEAYSHAoYU3R1YkNh",
@@ -172,7 +172,13 @@ namespace Tango.PMR.Common {
"dGF0dXNVcGRhdGVSZXF1ZXN0EKhGEiUKIFN0YXJ0TWFjaGluZVN0YXR1c1Vw",
"ZGF0ZVJlc3BvbnNlEKlGEiMKHlN0b3BNYWNoaW5lU3RhdHVzVXBkYXRlUmVx",
"dWVzdBCqRhIkCh9TdG9wTWFjaGluZVN0YXR1c1VwZGF0ZVJlc3BvbnNlEKtG",
- "QhwKGmNvbS50d2luZS50YW5nby5wbXIuY29tbW9uYgZwcm90bzM="));
+ "EhoKFVN0YXJ0UG93ZXJEb3duUmVxdWVzdBCQThIbChZTdGFydFBvd2VyRG93",
+ "blJlc3BvbnNlEJFOEhoKFUFib3J0UG93ZXJEb3duUmVxdWVzdBCSThIbChZB",
+ "Ym9ydFBvd2VyRG93blJlc3BvbnNlEJNOEh4KGVN0YXJ0VGhyZWFkTG9hZGlu",
+ "Z1JlcXVlc3QQ+FUSHwoaU3RhcnRUaHJlYWRMb2FkaW5nUmVzcG9uc2UQ+VUS",
+ "IQocQ29udGludWVUaHJlYWRMb2FkaW5nUmVxdWVzdBD6VRIiCh1Db250aW51",
+ "ZVRocmVhZExvYWRpbmdSZXNwb25zZRD7VUIcChpjb20udHdpbmUudGFuZ28u",
+ "cG1yLmNvbW1vbmIGcHJvdG8z"));
descriptor = pbr::FileDescriptor.FromGeneratedCode(descriptorData,
new pbr::FileDescriptor[] { },
new pbr::GeneratedClrTypeInfo(new[] {typeof(global::Tango.PMR.Common.MessageType), }, null));
@@ -450,6 +456,20 @@ namespace Tango.PMR.Common {
[pbr::OriginalName("StartMachineStatusUpdateResponse")] StartMachineStatusUpdateResponse = 9001,
[pbr::OriginalName("StopMachineStatusUpdateRequest")] StopMachineStatusUpdateRequest = 9002,
[pbr::OriginalName("StopMachineStatusUpdateResponse")] StopMachineStatusUpdateResponse = 9003,
+ /// <summary>
+ ///Power
+ /// </summary>
+ [pbr::OriginalName("StartPowerDownRequest")] StartPowerDownRequest = 10000,
+ [pbr::OriginalName("StartPowerDownResponse")] StartPowerDownResponse = 10001,
+ [pbr::OriginalName("AbortPowerDownRequest")] AbortPowerDownRequest = 10002,
+ [pbr::OriginalName("AbortPowerDownResponse")] AbortPowerDownResponse = 10003,
+ /// <summary>
+ ///Thread Loading
+ /// </summary>
+ [pbr::OriginalName("StartThreadLoadingRequest")] StartThreadLoadingRequest = 11000,
+ [pbr::OriginalName("StartThreadLoadingResponse")] StartThreadLoadingResponse = 11001,
+ [pbr::OriginalName("ContinueThreadLoadingRequest")] ContinueThreadLoadingRequest = 11002,
+ [pbr::OriginalName("ContinueThreadLoadingResponse")] ContinueThreadLoadingResponse = 11003,
}
#endregion
diff --git a/Software/Visual_Studio/Tango.PMR/Diagnostics/StartThreadLoadingUpdateResponse.cs b/Software/Visual_Studio/Tango.PMR/Diagnostics/StartThreadLoadingUpdateResponse.cs
deleted file mode 100644
index 0c62e31c7..000000000
--- a/Software/Visual_Studio/Tango.PMR/Diagnostics/StartThreadLoadingUpdateResponse.cs
+++ /dev/null
@@ -1,162 +0,0 @@
-// Generated by the protocol buffer compiler. DO NOT EDIT!
-// source: StartThreadLoadingUpdateResponse.proto
-#pragma warning disable 1591, 0612, 3021
-#region Designer generated code
-
-using pb = global::Google.Protobuf;
-using pbc = global::Google.Protobuf.Collections;
-using pbr = global::Google.Protobuf.Reflection;
-using scg = global::System.Collections.Generic;
-namespace Tango.PMR.Diagnostics {
-
- /// <summary>Holder for reflection information generated from StartThreadLoadingUpdateResponse.proto</summary>
- public static partial class StartThreadLoadingUpdateResponseReflection {
-
- #region Descriptor
- /// <summary>File descriptor for StartThreadLoadingUpdateResponse.proto</summary>
- public static pbr::FileDescriptor Descriptor {
- get { return descriptor; }
- }
- private static pbr::FileDescriptor descriptor;
-
- static StartThreadLoadingUpdateResponseReflection() {
- byte[] descriptorData = global::System.Convert.FromBase64String(
- string.Concat(
- "CiZTdGFydFRocmVhZExvYWRpbmdVcGRhdGVSZXNwb25zZS5wcm90bxIVVGFu",
- "Z28uUE1SLkRpYWdub3N0aWNzGhhUaHJlYWRMb2FkaW5nU3RhdGUucHJvdG8i",
- "aQogU3RhcnRUaHJlYWRMb2FkaW5nVXBkYXRlUmVzcG9uc2USRQoSVGhyZWFk",
- "TG9hZGluZ1N0YXRlGAEgASgOMikuVGFuZ28uUE1SLkRpYWdub3N0aWNzLlRo",
- "cmVhZExvYWRpbmdTdGF0ZUIhCh9jb20udHdpbmUudGFuZ28ucG1yLmRpYWdu",
- "b3N0aWNzYgZwcm90bzM="));
- descriptor = pbr::FileDescriptor.FromGeneratedCode(descriptorData,
- new pbr::FileDescriptor[] { global::Tango.PMR.Diagnostics.ThreadLoadingStateReflection.Descriptor, },
- new pbr::GeneratedClrTypeInfo(null, new pbr::GeneratedClrTypeInfo[] {
- new pbr::GeneratedClrTypeInfo(typeof(global::Tango.PMR.Diagnostics.StartThreadLoadingUpdateResponse), global::Tango.PMR.Diagnostics.StartThreadLoadingUpdateResponse.Parser, new[]{ "ThreadLoadingState" }, null, null, null)
- }));
- }
- #endregion
-
- }
- #region Messages
- public sealed partial class StartThreadLoadingUpdateResponse : pb::IMessage<StartThreadLoadingUpdateResponse> {
- private static readonly pb::MessageParser<StartThreadLoadingUpdateResponse> _parser = new pb::MessageParser<StartThreadLoadingUpdateResponse>(() => new StartThreadLoadingUpdateResponse());
- [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
- public static pb::MessageParser<StartThreadLoadingUpdateResponse> Parser { get { return _parser; } }
-
- [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
- public static pbr::MessageDescriptor Descriptor {
- get { return global::Tango.PMR.Diagnostics.StartThreadLoadingUpdateResponseReflection.Descriptor.MessageTypes[0]; }
- }
-
- [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
- pbr::MessageDescriptor pb::IMessage.Descriptor {
- get { return Descriptor; }
- }
-
- [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
- public StartThreadLoadingUpdateResponse() {
- OnConstruction();
- }
-
- partial void OnConstruction();
-
- [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
- public StartThreadLoadingUpdateResponse(StartThreadLoadingUpdateResponse other) : this() {
- threadLoadingState_ = other.threadLoadingState_;
- }
-
- [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
- public StartThreadLoadingUpdateResponse Clone() {
- return new StartThreadLoadingUpdateResponse(this);
- }
-
- /// <summary>Field number for the "ThreadLoadingState" field.</summary>
- public const int ThreadLoadingStateFieldNumber = 1;
- private global::Tango.PMR.Diagnostics.ThreadLoadingState threadLoadingState_ = 0;
- [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
- public global::Tango.PMR.Diagnostics.ThreadLoadingState ThreadLoadingState {
- get { return threadLoadingState_; }
- set {
- threadLoadingState_ = value;
- }
- }
-
- [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
- public override bool Equals(object other) {
- return Equals(other as StartThreadLoadingUpdateResponse);
- }
-
- [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
- public bool Equals(StartThreadLoadingUpdateResponse other) {
- if (ReferenceEquals(other, null)) {
- return false;
- }
- if (ReferenceEquals(other, this)) {
- return true;
- }
- if (ThreadLoadingState != other.ThreadLoadingState) return false;
- return true;
- }
-
- [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
- public override int GetHashCode() {
- int hash = 1;
- if (ThreadLoadingState != 0) hash ^= ThreadLoadingState.GetHashCode();
- return hash;
- }
-
- [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
- public override string ToString() {
- return pb::JsonFormatter.ToDiagnosticString(this);
- }
-
- [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
- public void WriteTo(pb::CodedOutputStream output) {
- if (ThreadLoadingState != 0) {
- output.WriteRawTag(8);
- output.WriteEnum((int) ThreadLoadingState);
- }
- }
-
- [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
- public int CalculateSize() {
- int size = 0;
- if (ThreadLoadingState != 0) {
- size += 1 + pb::CodedOutputStream.ComputeEnumSize((int) ThreadLoadingState);
- }
- return size;
- }
-
- [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
- public void MergeFrom(StartThreadLoadingUpdateResponse other) {
- if (other == null) {
- return;
- }
- if (other.ThreadLoadingState != 0) {
- ThreadLoadingState = other.ThreadLoadingState;
- }
- }
-
- [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
- public void MergeFrom(pb::CodedInputStream input) {
- uint tag;
- while ((tag = input.ReadTag()) != 0) {
- switch(tag) {
- default:
- input.SkipLastField();
- break;
- case 8: {
- threadLoadingState_ = (global::Tango.PMR.Diagnostics.ThreadLoadingState) input.ReadEnum();
- break;
- }
- }
- }
- }
-
- }
-
- #endregion
-
-}
-
-#endregion Designer generated code
diff --git a/Software/Visual_Studio/Tango.PMR/Diagnostics/ThreadLoadingState.cs b/Software/Visual_Studio/Tango.PMR/Diagnostics/ThreadLoadingState.cs
deleted file mode 100644
index 8322cbef4..000000000
--- a/Software/Visual_Studio/Tango.PMR/Diagnostics/ThreadLoadingState.cs
+++ /dev/null
@@ -1,97 +0,0 @@
-// Generated by the protocol buffer compiler. DO NOT EDIT!
-// source: ThreadLoadingState.proto
-#pragma warning disable 1591, 0612, 3021
-#region Designer generated code
-
-using pb = global::Google.Protobuf;
-using pbc = global::Google.Protobuf.Collections;
-using pbr = global::Google.Protobuf.Reflection;
-using scg = global::System.Collections.Generic;
-namespace Tango.PMR.Diagnostics {
-
- /// <summary>Holder for reflection information generated from ThreadLoadingState.proto</summary>
- public static partial class ThreadLoadingStateReflection {
-
- #region Descriptor
- /// <summary>File descriptor for ThreadLoadingState.proto</summary>
- public static pbr::FileDescriptor Descriptor {
- get { return descriptor; }
- }
- private static pbr::FileDescriptor descriptor;
-
- static ThreadLoadingStateReflection() {
- byte[] descriptorData = global::System.Convert.FromBase64String(
- string.Concat(
- "ChhUaHJlYWRMb2FkaW5nU3RhdGUucHJvdG8SFVRhbmdvLlBNUi5EaWFnbm9z",
- "dGljcyq1AwoSVGhyZWFkTG9hZGluZ1N0YXRlEhIKDlRocmVhZExvYWRJbml0",
- "EAASGAoUVGhyZWFkTG9hZFJlZHVjZUhlYXQQARInCiNUaHJlYWRMb2FkU2V0",
- "TG9hZEFybVRvU3RhcnRQb3NpdGlvbhACEhgKFFRocmVhZExvYWRPcGVuQ292",
- "ZXJzEAMSGQoVVGhyZWFkTG9hZExpZnREYW5jZXJzEAQSGQoVVGhyZWFkTG9h",
- "ZExpZnRSb2NrZXJzEAUSHAoYVGhyZWFkTG9hZEluaXRpYWxUZW5zaW9uEAYS",
- "GgoWVGhyZWFkTG9hZENsb3NlUm9ja2VycxAHEhoKFlRocmVhZExvYWRDbG9z",
- "ZURhbmNlcnMQCBIXChNUaHJlYWRMb2FkQ2xvc2VMaWRzEAkSJAogVGhyZWFk",
- "TG9hZEpvZ0ZlZWRlclRvTWlkZGxlUG9pbnQQChIaChZUaHJlYWRMb2FkRHJ5",
- "ZXJMb2FkaW5nEAsSGwoXVGhyZWFkTG9hZFJlc3VtZUhlYXRpbmcQDBIXChNU",
- "aHJlYWRMb2FkSm9nVGhyZWFkEA0SEQoNVGhyZWFkTG9hZEVuZBAOQiEKH2Nv",
- "bS50d2luZS50YW5nby5wbXIuZGlhZ25vc3RpY3NiBnByb3RvMw=="));
- descriptor = pbr::FileDescriptor.FromGeneratedCode(descriptorData,
- new pbr::FileDescriptor[] { },
- new pbr::GeneratedClrTypeInfo(new[] {typeof(global::Tango.PMR.Diagnostics.ThreadLoadingState), }, null));
- }
- #endregion
-
- }
- #region Enums
- public enum ThreadLoadingState {
- [pbr::OriginalName("ThreadLoadInit")] ThreadLoadInit = 0,
- /// <summary>
- ///Heaters Off; Dryer Blower Off; Blower Low;
- /// </summary>
- [pbr::OriginalName("ThreadLoadReduceHeat")] ThreadLoadReduceHeat = 1,
- /// <summary>
- ///Use Notation How Many Rotations In The Dryer; Or Check Against Stopper. Move Slowly
- /// </summary>
- [pbr::OriginalName("ThreadLoadSetLoadArmToStartPosition")] ThreadLoadSetLoadArmToStartPosition = 2,
- /// <summary>
- ///Open Dyeing Head Cover And Dryer Lid
- /// </summary>
- [pbr::OriginalName("ThreadLoadOpenCovers")] ThreadLoadOpenCovers = 3,
- [pbr::OriginalName("ThreadLoadLiftDancers")] ThreadLoadLiftDancers = 4,
- /// <summary>
- ///Machine Is Ready. Send Message; Start Timer To Close Lids; Wait For Operator Response
- /// </summary>
- [pbr::OriginalName("ThreadLoadLiftRockers")] ThreadLoadLiftRockers = 5,
- /// <summary>
- ///Check Spool Presencerun Winder Until Break Sensor Is Identifieing Movement For A Second
- /// </summary>
- [pbr::OriginalName("ThreadLoadInitialTension")] ThreadLoadInitialTension = 6,
- [pbr::OriginalName("ThreadLoadCloseRockers")] ThreadLoadCloseRockers = 7,
- /// <summary>
- ///Send Dancer Motors To Preset Location; Check That The Dancers Are On The Thread
- /// </summary>
- [pbr::OriginalName("ThreadLoadCloseDancers")] ThreadLoadCloseDancers = 8,
- [pbr::OriginalName("ThreadLoadCloseLids")] ThreadLoadCloseLids = 9,
- /// <summary>
- ///Jog The Feeder Motor Until The Feeder Dancer Is At Middle Position
- /// </summary>
- [pbr::OriginalName("ThreadLoadJogFeederToMiddlePoint")] ThreadLoadJogFeederToMiddlePoint = 10,
- /// <summary>
- ///Start Feeder Pid Rotate Loading Arm Counter Thread Direction X Circles According To Rml. Feeder Speed Is 40
- /// </summary>
- [pbr::OriginalName("ThreadLoadDryerLoading")] ThreadLoadDryerLoading = 11,
- /// <summary>
- ///Keep Notation How Many Rotations In The Dryer
- /// </summary>
- [pbr::OriginalName("ThreadLoadResumeHeating")] ThreadLoadResumeHeating = 12,
- /// <summary>
- ///Jog Thread Shortly To Make Sure Spool Is Running. Report End Of Loading
- /// </summary>
- [pbr::OriginalName("ThreadLoadJogThread")] ThreadLoadJogThread = 13,
- [pbr::OriginalName("ThreadLoadEnd")] ThreadLoadEnd = 14,
- }
-
- #endregion
-
-}
-
-#endregion Designer generated code
diff --git a/Software/Visual_Studio/Tango.PMR/Power/AbortPowerDownRequest.cs b/Software/Visual_Studio/Tango.PMR/Power/AbortPowerDownRequest.cs
new file mode 100644
index 000000000..77578d7c5
--- /dev/null
+++ b/Software/Visual_Studio/Tango.PMR/Power/AbortPowerDownRequest.cs
@@ -0,0 +1,131 @@
+// Generated by the protocol buffer compiler. DO NOT EDIT!
+// source: AbortPowerDownRequest.proto
+#pragma warning disable 1591, 0612, 3021
+#region Designer generated code
+
+using pb = global::Google.Protobuf;
+using pbc = global::Google.Protobuf.Collections;
+using pbr = global::Google.Protobuf.Reflection;
+using scg = global::System.Collections.Generic;
+namespace Tango.PMR.Power {
+
+ /// <summary>Holder for reflection information generated from AbortPowerDownRequest.proto</summary>
+ public static partial class AbortPowerDownRequestReflection {
+
+ #region Descriptor
+ /// <summary>File descriptor for AbortPowerDownRequest.proto</summary>
+ public static pbr::FileDescriptor Descriptor {
+ get { return descriptor; }
+ }
+ private static pbr::FileDescriptor descriptor;
+
+ static AbortPowerDownRequestReflection() {
+ byte[] descriptorData = global::System.Convert.FromBase64String(
+ string.Concat(
+ "ChtBYm9ydFBvd2VyRG93blJlcXVlc3QucHJvdG8SD1RhbmdvLlBNUi5Qb3dl",
+ "ciIXChVBYm9ydFBvd2VyRG93blJlcXVlc3RCGwoZY29tLnR3aW5lLnRhbmdv",
+ "LnBtci5wb3dlcmIGcHJvdG8z"));
+ descriptor = pbr::FileDescriptor.FromGeneratedCode(descriptorData,
+ new pbr::FileDescriptor[] { },
+ new pbr::GeneratedClrTypeInfo(null, new pbr::GeneratedClrTypeInfo[] {
+ new pbr::GeneratedClrTypeInfo(typeof(global::Tango.PMR.Power.AbortPowerDownRequest), global::Tango.PMR.Power.AbortPowerDownRequest.Parser, null, null, null, null)
+ }));
+ }
+ #endregion
+
+ }
+ #region Messages
+ public sealed partial class AbortPowerDownRequest : pb::IMessage<AbortPowerDownRequest> {
+ private static readonly pb::MessageParser<AbortPowerDownRequest> _parser = new pb::MessageParser<AbortPowerDownRequest>(() => new AbortPowerDownRequest());
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public static pb::MessageParser<AbortPowerDownRequest> Parser { get { return _parser; } }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public static pbr::MessageDescriptor Descriptor {
+ get { return global::Tango.PMR.Power.AbortPowerDownRequestReflection.Descriptor.MessageTypes[0]; }
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ pbr::MessageDescriptor pb::IMessage.Descriptor {
+ get { return Descriptor; }
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public AbortPowerDownRequest() {
+ OnConstruction();
+ }
+
+ partial void OnConstruction();
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public AbortPowerDownRequest(AbortPowerDownRequest other) : this() {
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public AbortPowerDownRequest Clone() {
+ return new AbortPowerDownRequest(this);
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public override bool Equals(object other) {
+ return Equals(other as AbortPowerDownRequest);
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public bool Equals(AbortPowerDownRequest other) {
+ if (ReferenceEquals(other, null)) {
+ return false;
+ }
+ if (ReferenceEquals(other, this)) {
+ return true;
+ }
+ return true;
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public override int GetHashCode() {
+ int hash = 1;
+ return hash;
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public override string ToString() {
+ return pb::JsonFormatter.ToDiagnosticString(this);
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public void WriteTo(pb::CodedOutputStream output) {
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public int CalculateSize() {
+ int size = 0;
+ return size;
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public void MergeFrom(AbortPowerDownRequest other) {
+ if (other == null) {
+ return;
+ }
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public void MergeFrom(pb::CodedInputStream input) {
+ uint tag;
+ while ((tag = input.ReadTag()) != 0) {
+ switch(tag) {
+ default:
+ input.SkipLastField();
+ break;
+ }
+ }
+ }
+
+ }
+
+ #endregion
+
+}
+
+#endregion Designer generated code
diff --git a/Software/Visual_Studio/Tango.PMR/Power/AbortPowerDownResponse.cs b/Software/Visual_Studio/Tango.PMR/Power/AbortPowerDownResponse.cs
new file mode 100644
index 000000000..b926e0818
--- /dev/null
+++ b/Software/Visual_Studio/Tango.PMR/Power/AbortPowerDownResponse.cs
@@ -0,0 +1,131 @@
+// Generated by the protocol buffer compiler. DO NOT EDIT!
+// source: AbortPowerDownResponse.proto
+#pragma warning disable 1591, 0612, 3021
+#region Designer generated code
+
+using pb = global::Google.Protobuf;
+using pbc = global::Google.Protobuf.Collections;
+using pbr = global::Google.Protobuf.Reflection;
+using scg = global::System.Collections.Generic;
+namespace Tango.PMR.Power {
+
+ /// <summary>Holder for reflection information generated from AbortPowerDownResponse.proto</summary>
+ public static partial class AbortPowerDownResponseReflection {
+
+ #region Descriptor
+ /// <summary>File descriptor for AbortPowerDownResponse.proto</summary>
+ public static pbr::FileDescriptor Descriptor {
+ get { return descriptor; }
+ }
+ private static pbr::FileDescriptor descriptor;
+
+ static AbortPowerDownResponseReflection() {
+ byte[] descriptorData = global::System.Convert.FromBase64String(
+ string.Concat(
+ "ChxBYm9ydFBvd2VyRG93blJlc3BvbnNlLnByb3RvEg9UYW5nby5QTVIuUG93",
+ "ZXIiGAoWQWJvcnRQb3dlckRvd25SZXNwb25zZUIbChljb20udHdpbmUudGFu",
+ "Z28ucG1yLnBvd2VyYgZwcm90bzM="));
+ descriptor = pbr::FileDescriptor.FromGeneratedCode(descriptorData,
+ new pbr::FileDescriptor[] { },
+ new pbr::GeneratedClrTypeInfo(null, new pbr::GeneratedClrTypeInfo[] {
+ new pbr::GeneratedClrTypeInfo(typeof(global::Tango.PMR.Power.AbortPowerDownResponse), global::Tango.PMR.Power.AbortPowerDownResponse.Parser, null, null, null, null)
+ }));
+ }
+ #endregion
+
+ }
+ #region Messages
+ public sealed partial class AbortPowerDownResponse : pb::IMessage<AbortPowerDownResponse> {
+ private static readonly pb::MessageParser<AbortPowerDownResponse> _parser = new pb::MessageParser<AbortPowerDownResponse>(() => new AbortPowerDownResponse());
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public static pb::MessageParser<AbortPowerDownResponse> Parser { get { return _parser; } }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public static pbr::MessageDescriptor Descriptor {
+ get { return global::Tango.PMR.Power.AbortPowerDownResponseReflection.Descriptor.MessageTypes[0]; }
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ pbr::MessageDescriptor pb::IMessage.Descriptor {
+ get { return Descriptor; }
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public AbortPowerDownResponse() {
+ OnConstruction();
+ }
+
+ partial void OnConstruction();
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public AbortPowerDownResponse(AbortPowerDownResponse other) : this() {
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public AbortPowerDownResponse Clone() {
+ return new AbortPowerDownResponse(this);
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public override bool Equals(object other) {
+ return Equals(other as AbortPowerDownResponse);
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public bool Equals(AbortPowerDownResponse other) {
+ if (ReferenceEquals(other, null)) {
+ return false;
+ }
+ if (ReferenceEquals(other, this)) {
+ return true;
+ }
+ return true;
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public override int GetHashCode() {
+ int hash = 1;
+ return hash;
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public override string ToString() {
+ return pb::JsonFormatter.ToDiagnosticString(this);
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public void WriteTo(pb::CodedOutputStream output) {
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public int CalculateSize() {
+ int size = 0;
+ return size;
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public void MergeFrom(AbortPowerDownResponse other) {
+ if (other == null) {
+ return;
+ }
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public void MergeFrom(pb::CodedInputStream input) {
+ uint tag;
+ while ((tag = input.ReadTag()) != 0) {
+ switch(tag) {
+ default:
+ input.SkipLastField();
+ break;
+ }
+ }
+ }
+
+ }
+
+ #endregion
+
+}
+
+#endregion Designer generated code
diff --git a/Software/Visual_Studio/Tango.PMR/Power/PowerDownState.cs b/Software/Visual_Studio/Tango.PMR/Power/PowerDownState.cs
new file mode 100644
index 000000000..92ac94dc2
--- /dev/null
+++ b/Software/Visual_Studio/Tango.PMR/Power/PowerDownState.cs
@@ -0,0 +1,48 @@
+// Generated by the protocol buffer compiler. DO NOT EDIT!
+// source: PowerDownState.proto
+#pragma warning disable 1591, 0612, 3021
+#region Designer generated code
+
+using pb = global::Google.Protobuf;
+using pbc = global::Google.Protobuf.Collections;
+using pbr = global::Google.Protobuf.Reflection;
+using scg = global::System.Collections.Generic;
+namespace Tango.PMR.Power {
+
+ /// <summary>Holder for reflection information generated from PowerDownState.proto</summary>
+ public static partial class PowerDownStateReflection {
+
+ #region Descriptor
+ /// <summary>File descriptor for PowerDownState.proto</summary>
+ public static pbr::FileDescriptor Descriptor {
+ get { return descriptor; }
+ }
+ private static pbr::FileDescriptor descriptor;
+
+ static PowerDownStateReflection() {
+ byte[] descriptorData = global::System.Convert.FromBase64String(
+ string.Concat(
+ "ChRQb3dlckRvd25TdGF0ZS5wcm90bxIPVGFuZ28uUE1SLlBvd2VyKikKDlBv",
+ "d2VyRG93blN0YXRlEggKBE5vbmUQABINCglDb21wbGV0ZWQQAUIbChljb20u",
+ "dHdpbmUudGFuZ28ucG1yLnBvd2VyYgZwcm90bzM="));
+ descriptor = pbr::FileDescriptor.FromGeneratedCode(descriptorData,
+ new pbr::FileDescriptor[] { },
+ new pbr::GeneratedClrTypeInfo(new[] {typeof(global::Tango.PMR.Power.PowerDownState), }, null));
+ }
+ #endregion
+
+ }
+ #region Enums
+ public enum PowerDownState {
+ /// <summary>
+ ///Fill the states.
+ /// </summary>
+ [pbr::OriginalName("None")] None = 0,
+ [pbr::OriginalName("Completed")] Completed = 1,
+ }
+
+ #endregion
+
+}
+
+#endregion Designer generated code
diff --git a/Software/Visual_Studio/Tango.PMR/Power/StartPowerDownRequest.cs b/Software/Visual_Studio/Tango.PMR/Power/StartPowerDownRequest.cs
new file mode 100644
index 000000000..a84a1e2e8
--- /dev/null
+++ b/Software/Visual_Studio/Tango.PMR/Power/StartPowerDownRequest.cs
@@ -0,0 +1,131 @@
+// Generated by the protocol buffer compiler. DO NOT EDIT!
+// source: StartPowerDownRequest.proto
+#pragma warning disable 1591, 0612, 3021
+#region Designer generated code
+
+using pb = global::Google.Protobuf;
+using pbc = global::Google.Protobuf.Collections;
+using pbr = global::Google.Protobuf.Reflection;
+using scg = global::System.Collections.Generic;
+namespace Tango.PMR.Power {
+
+ /// <summary>Holder for reflection information generated from StartPowerDownRequest.proto</summary>
+ public static partial class StartPowerDownRequestReflection {
+
+ #region Descriptor
+ /// <summary>File descriptor for StartPowerDownRequest.proto</summary>
+ public static pbr::FileDescriptor Descriptor {
+ get { return descriptor; }
+ }
+ private static pbr::FileDescriptor descriptor;
+
+ static StartPowerDownRequestReflection() {
+ byte[] descriptorData = global::System.Convert.FromBase64String(
+ string.Concat(
+ "ChtTdGFydFBvd2VyRG93blJlcXVlc3QucHJvdG8SD1RhbmdvLlBNUi5Qb3dl",
+ "ciIXChVTdGFydFBvd2VyRG93blJlcXVlc3RCGwoZY29tLnR3aW5lLnRhbmdv",
+ "LnBtci5wb3dlcmIGcHJvdG8z"));
+ descriptor = pbr::FileDescriptor.FromGeneratedCode(descriptorData,
+ new pbr::FileDescriptor[] { },
+ new pbr::GeneratedClrTypeInfo(null, new pbr::GeneratedClrTypeInfo[] {
+ new pbr::GeneratedClrTypeInfo(typeof(global::Tango.PMR.Power.StartPowerDownRequest), global::Tango.PMR.Power.StartPowerDownRequest.Parser, null, null, null, null)
+ }));
+ }
+ #endregion
+
+ }
+ #region Messages
+ public sealed partial class StartPowerDownRequest : pb::IMessage<StartPowerDownRequest> {
+ private static readonly pb::MessageParser<StartPowerDownRequest> _parser = new pb::MessageParser<StartPowerDownRequest>(() => new StartPowerDownRequest());
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public static pb::MessageParser<StartPowerDownRequest> Parser { get { return _parser; } }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public static pbr::MessageDescriptor Descriptor {
+ get { return global::Tango.PMR.Power.StartPowerDownRequestReflection.Descriptor.MessageTypes[0]; }
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ pbr::MessageDescriptor pb::IMessage.Descriptor {
+ get { return Descriptor; }
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public StartPowerDownRequest() {
+ OnConstruction();
+ }
+
+ partial void OnConstruction();
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public StartPowerDownRequest(StartPowerDownRequest other) : this() {
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public StartPowerDownRequest Clone() {
+ return new StartPowerDownRequest(this);
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public override bool Equals(object other) {
+ return Equals(other as StartPowerDownRequest);
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public bool Equals(StartPowerDownRequest other) {
+ if (ReferenceEquals(other, null)) {
+ return false;
+ }
+ if (ReferenceEquals(other, this)) {
+ return true;
+ }
+ return true;
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public override int GetHashCode() {
+ int hash = 1;
+ return hash;
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public override string ToString() {
+ return pb::JsonFormatter.ToDiagnosticString(this);
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public void WriteTo(pb::CodedOutputStream output) {
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public int CalculateSize() {
+ int size = 0;
+ return size;
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public void MergeFrom(StartPowerDownRequest other) {
+ if (other == null) {
+ return;
+ }
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public void MergeFrom(pb::CodedInputStream input) {
+ uint tag;
+ while ((tag = input.ReadTag()) != 0) {
+ switch(tag) {
+ default:
+ input.SkipLastField();
+ break;
+ }
+ }
+ }
+
+ }
+
+ #endregion
+
+}
+
+#endregion Designer generated code
diff --git a/Software/Visual_Studio/Tango.PMR/Power/StartPowerDownResponse.cs b/Software/Visual_Studio/Tango.PMR/Power/StartPowerDownResponse.cs
new file mode 100644
index 000000000..6f5e9adf3
--- /dev/null
+++ b/Software/Visual_Studio/Tango.PMR/Power/StartPowerDownResponse.cs
@@ -0,0 +1,217 @@
+// Generated by the protocol buffer compiler. DO NOT EDIT!
+// source: StartPowerDownResponse.proto
+#pragma warning disable 1591, 0612, 3021
+#region Designer generated code
+
+using pb = global::Google.Protobuf;
+using pbc = global::Google.Protobuf.Collections;
+using pbr = global::Google.Protobuf.Reflection;
+using scg = global::System.Collections.Generic;
+namespace Tango.PMR.Power {
+
+ /// <summary>Holder for reflection information generated from StartPowerDownResponse.proto</summary>
+ public static partial class StartPowerDownResponseReflection {
+
+ #region Descriptor
+ /// <summary>File descriptor for StartPowerDownResponse.proto</summary>
+ public static pbr::FileDescriptor Descriptor {
+ get { return descriptor; }
+ }
+ private static pbr::FileDescriptor descriptor;
+
+ static StartPowerDownResponseReflection() {
+ byte[] descriptorData = global::System.Convert.FromBase64String(
+ string.Concat(
+ "ChxTdGFydFBvd2VyRG93blJlc3BvbnNlLnByb3RvEg9UYW5nby5QTVIuUG93",
+ "ZXIaFFBvd2VyRG93blN0YXRlLnByb3RvInUKFlN0YXJ0UG93ZXJEb3duUmVz",
+ "cG9uc2USLgoFU3RhdGUYASABKA4yHy5UYW5nby5QTVIuUG93ZXIuUG93ZXJE",
+ "b3duU3RhdGUSGgoSUHJvZ3Jlc3NQZXJjZW50YWdlGAIgASgBEg8KB01lc3Nh",
+ "Z2UYAyABKAlCGwoZY29tLnR3aW5lLnRhbmdvLnBtci5wb3dlcmIGcHJvdG8z"));
+ descriptor = pbr::FileDescriptor.FromGeneratedCode(descriptorData,
+ new pbr::FileDescriptor[] { global::Tango.PMR.Power.PowerDownStateReflection.Descriptor, },
+ new pbr::GeneratedClrTypeInfo(null, new pbr::GeneratedClrTypeInfo[] {
+ new pbr::GeneratedClrTypeInfo(typeof(global::Tango.PMR.Power.StartPowerDownResponse), global::Tango.PMR.Power.StartPowerDownResponse.Parser, new[]{ "State", "ProgressPercentage", "Message" }, null, null, null)
+ }));
+ }
+ #endregion
+
+ }
+ #region Messages
+ public sealed partial class StartPowerDownResponse : pb::IMessage<StartPowerDownResponse> {
+ private static readonly pb::MessageParser<StartPowerDownResponse> _parser = new pb::MessageParser<StartPowerDownResponse>(() => new StartPowerDownResponse());
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public static pb::MessageParser<StartPowerDownResponse> Parser { get { return _parser; } }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public static pbr::MessageDescriptor Descriptor {
+ get { return global::Tango.PMR.Power.StartPowerDownResponseReflection.Descriptor.MessageTypes[0]; }
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ pbr::MessageDescriptor pb::IMessage.Descriptor {
+ get { return Descriptor; }
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public StartPowerDownResponse() {
+ OnConstruction();
+ }
+
+ partial void OnConstruction();
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public StartPowerDownResponse(StartPowerDownResponse other) : this() {
+ state_ = other.state_;
+ progressPercentage_ = other.progressPercentage_;
+ message_ = other.message_;
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public StartPowerDownResponse Clone() {
+ return new StartPowerDownResponse(this);
+ }
+
+ /// <summary>Field number for the "State" field.</summary>
+ public const int StateFieldNumber = 1;
+ private global::Tango.PMR.Power.PowerDownState state_ = 0;
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public global::Tango.PMR.Power.PowerDownState State {
+ get { return state_; }
+ set {
+ state_ = value;
+ }
+ }
+
+ /// <summary>Field number for the "ProgressPercentage" field.</summary>
+ public const int ProgressPercentageFieldNumber = 2;
+ private double progressPercentage_;
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public double ProgressPercentage {
+ get { return progressPercentage_; }
+ set {
+ progressPercentage_ = value;
+ }
+ }
+
+ /// <summary>Field number for the "Message" field.</summary>
+ public const int MessageFieldNumber = 3;
+ private string message_ = "";
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public string Message {
+ get { return message_; }
+ set {
+ message_ = pb::ProtoPreconditions.CheckNotNull(value, "value");
+ }
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public override bool Equals(object other) {
+ return Equals(other as StartPowerDownResponse);
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public bool Equals(StartPowerDownResponse other) {
+ if (ReferenceEquals(other, null)) {
+ return false;
+ }
+ if (ReferenceEquals(other, this)) {
+ return true;
+ }
+ if (State != other.State) return false;
+ if (ProgressPercentage != other.ProgressPercentage) return false;
+ if (Message != other.Message) return false;
+ return true;
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public override int GetHashCode() {
+ int hash = 1;
+ if (State != 0) hash ^= State.GetHashCode();
+ if (ProgressPercentage != 0D) hash ^= ProgressPercentage.GetHashCode();
+ if (Message.Length != 0) hash ^= Message.GetHashCode();
+ return hash;
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public override string ToString() {
+ return pb::JsonFormatter.ToDiagnosticString(this);
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public void WriteTo(pb::CodedOutputStream output) {
+ if (State != 0) {
+ output.WriteRawTag(8);
+ output.WriteEnum((int) State);
+ }
+ if (ProgressPercentage != 0D) {
+ output.WriteRawTag(17);
+ output.WriteDouble(ProgressPercentage);
+ }
+ if (Message.Length != 0) {
+ output.WriteRawTag(26);
+ output.WriteString(Message);
+ }
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public int CalculateSize() {
+ int size = 0;
+ if (State != 0) {
+ size += 1 + pb::CodedOutputStream.ComputeEnumSize((int) State);
+ }
+ if (ProgressPercentage != 0D) {
+ size += 1 + 8;
+ }
+ if (Message.Length != 0) {
+ size += 1 + pb::CodedOutputStream.ComputeStringSize(Message);
+ }
+ return size;
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public void MergeFrom(StartPowerDownResponse other) {
+ if (other == null) {
+ return;
+ }
+ if (other.State != 0) {
+ State = other.State;
+ }
+ if (other.ProgressPercentage != 0D) {
+ ProgressPercentage = other.ProgressPercentage;
+ }
+ if (other.Message.Length != 0) {
+ Message = other.Message;
+ }
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public void MergeFrom(pb::CodedInputStream input) {
+ uint tag;
+ while ((tag = input.ReadTag()) != 0) {
+ switch(tag) {
+ default:
+ input.SkipLastField();
+ break;
+ case 8: {
+ state_ = (global::Tango.PMR.Power.PowerDownState) input.ReadEnum();
+ break;
+ }
+ case 17: {
+ ProgressPercentage = input.ReadDouble();
+ break;
+ }
+ case 26: {
+ Message = input.ReadString();
+ break;
+ }
+ }
+ }
+ }
+
+ }
+
+ #endregion
+
+}
+
+#endregion Designer generated code
diff --git a/Software/Visual_Studio/Tango.PMR/Tango.PMR.csproj b/Software/Visual_Studio/Tango.PMR/Tango.PMR.csproj
index 8a3c8a73a..ad4e8e170 100644
--- a/Software/Visual_Studio/Tango.PMR/Tango.PMR.csproj
+++ b/Software/Visual_Studio/Tango.PMR/Tango.PMR.csproj
@@ -131,8 +131,6 @@
<Compile Include="Diagnostics\StartDiagnosticsResponse.cs" />
<Compile Include="Diagnostics\StartEventsNotificationRequest.cs" />
<Compile Include="Diagnostics\StartEventsNotificationResponse.cs" />
- <Compile Include="Diagnostics\StartThreadLoadingUpdateRequest.cs" />
- <Compile Include="Diagnostics\StartThreadLoadingUpdateResponse.cs" />
<Compile Include="Diagnostics\StopCartridgesUpdateRequest.cs" />
<Compile Include="Diagnostics\StopCartridgesUpdateResponse.cs" />
<Compile Include="Diagnostics\StopDiagnosticsRequest.cs" />
@@ -143,7 +141,6 @@
<Compile Include="Diagnostics\ThreadAbortJoggingResponse.cs" />
<Compile Include="Diagnostics\ThreadJoggingRequest.cs" />
<Compile Include="Diagnostics\ThreadJoggingResponse.cs" />
- <Compile Include="Diagnostics\ThreadLoadingState.cs" />
<Compile Include="Diagnostics\ValueComponent.cs" />
<Compile Include="Diagnostics\ValueComponentState.cs" />
<Compile Include="Diagnostics\ValveState.cs" />
@@ -312,7 +309,7 @@
</PropertyGroup>
<ProjectExtensions>
<VisualStudio>
- <UserProperties BuildVersion_StartDate="2000/1/1" BuildVersion_UseGlobalSettings="False" BuildVersion_BuildVersioningStyle="None.None.Increment.TimeStamp" BuildVersion_UpdateAssemblyVersion="True" BuildVersion_AssemblyInfoFilename="Properties\AssemblyInfo.cs" />
+ <UserProperties BuildVersion_AssemblyInfoFilename="Properties\AssemblyInfo.cs" BuildVersion_UpdateAssemblyVersion="True" BuildVersion_BuildVersioningStyle="None.None.Increment.TimeStamp" BuildVersion_UseGlobalSettings="False" BuildVersion_StartDate="2000/1/1" />
</VisualStudio>
</ProjectExtensions>
</Project> \ No newline at end of file
diff --git a/Software/Visual_Studio/Tango.PMR/ThreadLoading/ContinueThreadLoadingRequest.cs b/Software/Visual_Studio/Tango.PMR/ThreadLoading/ContinueThreadLoadingRequest.cs
new file mode 100644
index 000000000..94c8b8f48
--- /dev/null
+++ b/Software/Visual_Studio/Tango.PMR/ThreadLoading/ContinueThreadLoadingRequest.cs
@@ -0,0 +1,168 @@
+// Generated by the protocol buffer compiler. DO NOT EDIT!
+// source: ContinueThreadLoadingRequest.proto
+#pragma warning disable 1591, 0612, 3021
+#region Designer generated code
+
+using pb = global::Google.Protobuf;
+using pbc = global::Google.Protobuf.Collections;
+using pbr = global::Google.Protobuf.Reflection;
+using scg = global::System.Collections.Generic;
+namespace Tango.PMR.ThreadLoading {
+
+ /// <summary>Holder for reflection information generated from ContinueThreadLoadingRequest.proto</summary>
+ public static partial class ContinueThreadLoadingRequestReflection {
+
+ #region Descriptor
+ /// <summary>File descriptor for ContinueThreadLoadingRequest.proto</summary>
+ public static pbr::FileDescriptor Descriptor {
+ get { return descriptor; }
+ }
+ private static pbr::FileDescriptor descriptor;
+
+ static ContinueThreadLoadingRequestReflection() {
+ byte[] descriptorData = global::System.Convert.FromBase64String(
+ string.Concat(
+ "CiJDb250aW51ZVRocmVhZExvYWRpbmdSZXF1ZXN0LnByb3RvEhdUYW5nby5Q",
+ "TVIuVGhyZWFkTG9hZGluZxoXUHJvY2Vzc1BhcmFtZXRlcnMucHJvdG8iYAoc",
+ "Q29udGludWVUaHJlYWRMb2FkaW5nUmVxdWVzdBJAChFQcm9jZXNzUGFyYW1l",
+ "dGVycxgBIAEoCzIlLlRhbmdvLlBNUi5QcmludGluZy5Qcm9jZXNzUGFyYW1l",
+ "dGVyc0IjCiFjb20udHdpbmUudGFuZ28ucG1yLnRocmVhZGxvYWRpbmdiBnBy",
+ "b3RvMw=="));
+ descriptor = pbr::FileDescriptor.FromGeneratedCode(descriptorData,
+ new pbr::FileDescriptor[] { global::Tango.PMR.Printing.ProcessParametersReflection.Descriptor, },
+ new pbr::GeneratedClrTypeInfo(null, new pbr::GeneratedClrTypeInfo[] {
+ new pbr::GeneratedClrTypeInfo(typeof(global::Tango.PMR.ThreadLoading.ContinueThreadLoadingRequest), global::Tango.PMR.ThreadLoading.ContinueThreadLoadingRequest.Parser, new[]{ "ProcessParameters" }, null, null, null)
+ }));
+ }
+ #endregion
+
+ }
+ #region Messages
+ public sealed partial class ContinueThreadLoadingRequest : pb::IMessage<ContinueThreadLoadingRequest> {
+ private static readonly pb::MessageParser<ContinueThreadLoadingRequest> _parser = new pb::MessageParser<ContinueThreadLoadingRequest>(() => new ContinueThreadLoadingRequest());
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public static pb::MessageParser<ContinueThreadLoadingRequest> Parser { get { return _parser; } }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public static pbr::MessageDescriptor Descriptor {
+ get { return global::Tango.PMR.ThreadLoading.ContinueThreadLoadingRequestReflection.Descriptor.MessageTypes[0]; }
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ pbr::MessageDescriptor pb::IMessage.Descriptor {
+ get { return Descriptor; }
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public ContinueThreadLoadingRequest() {
+ OnConstruction();
+ }
+
+ partial void OnConstruction();
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public ContinueThreadLoadingRequest(ContinueThreadLoadingRequest other) : this() {
+ ProcessParameters = other.processParameters_ != null ? other.ProcessParameters.Clone() : null;
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public ContinueThreadLoadingRequest Clone() {
+ return new ContinueThreadLoadingRequest(this);
+ }
+
+ /// <summary>Field number for the "ProcessParameters" field.</summary>
+ public const int ProcessParametersFieldNumber = 1;
+ private global::Tango.PMR.Printing.ProcessParameters processParameters_;
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public global::Tango.PMR.Printing.ProcessParameters ProcessParameters {
+ get { return processParameters_; }
+ set {
+ processParameters_ = value;
+ }
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public override bool Equals(object other) {
+ return Equals(other as ContinueThreadLoadingRequest);
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public bool Equals(ContinueThreadLoadingRequest other) {
+ if (ReferenceEquals(other, null)) {
+ return false;
+ }
+ if (ReferenceEquals(other, this)) {
+ return true;
+ }
+ if (!object.Equals(ProcessParameters, other.ProcessParameters)) return false;
+ return true;
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public override int GetHashCode() {
+ int hash = 1;
+ if (processParameters_ != null) hash ^= ProcessParameters.GetHashCode();
+ return hash;
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public override string ToString() {
+ return pb::JsonFormatter.ToDiagnosticString(this);
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public void WriteTo(pb::CodedOutputStream output) {
+ if (processParameters_ != null) {
+ output.WriteRawTag(10);
+ output.WriteMessage(ProcessParameters);
+ }
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public int CalculateSize() {
+ int size = 0;
+ if (processParameters_ != null) {
+ size += 1 + pb::CodedOutputStream.ComputeMessageSize(ProcessParameters);
+ }
+ return size;
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public void MergeFrom(ContinueThreadLoadingRequest other) {
+ if (other == null) {
+ return;
+ }
+ if (other.processParameters_ != null) {
+ if (processParameters_ == null) {
+ processParameters_ = new global::Tango.PMR.Printing.ProcessParameters();
+ }
+ ProcessParameters.MergeFrom(other.ProcessParameters);
+ }
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public void MergeFrom(pb::CodedInputStream input) {
+ uint tag;
+ while ((tag = input.ReadTag()) != 0) {
+ switch(tag) {
+ default:
+ input.SkipLastField();
+ break;
+ case 10: {
+ if (processParameters_ == null) {
+ processParameters_ = new global::Tango.PMR.Printing.ProcessParameters();
+ }
+ input.ReadMessage(processParameters_);
+ break;
+ }
+ }
+ }
+ }
+
+ }
+
+ #endregion
+
+}
+
+#endregion Designer generated code
diff --git a/Software/Visual_Studio/Tango.PMR/ThreadLoading/ContinueThreadLoadingResponse.cs b/Software/Visual_Studio/Tango.PMR/ThreadLoading/ContinueThreadLoadingResponse.cs
new file mode 100644
index 000000000..0300e573b
--- /dev/null
+++ b/Software/Visual_Studio/Tango.PMR/ThreadLoading/ContinueThreadLoadingResponse.cs
@@ -0,0 +1,132 @@
+// Generated by the protocol buffer compiler. DO NOT EDIT!
+// source: ContinueThreadLoadingResponse.proto
+#pragma warning disable 1591, 0612, 3021
+#region Designer generated code
+
+using pb = global::Google.Protobuf;
+using pbc = global::Google.Protobuf.Collections;
+using pbr = global::Google.Protobuf.Reflection;
+using scg = global::System.Collections.Generic;
+namespace Tango.PMR.ThreadLoading {
+
+ /// <summary>Holder for reflection information generated from ContinueThreadLoadingResponse.proto</summary>
+ public static partial class ContinueThreadLoadingResponseReflection {
+
+ #region Descriptor
+ /// <summary>File descriptor for ContinueThreadLoadingResponse.proto</summary>
+ public static pbr::FileDescriptor Descriptor {
+ get { return descriptor; }
+ }
+ private static pbr::FileDescriptor descriptor;
+
+ static ContinueThreadLoadingResponseReflection() {
+ byte[] descriptorData = global::System.Convert.FromBase64String(
+ string.Concat(
+ "CiNDb250aW51ZVRocmVhZExvYWRpbmdSZXNwb25zZS5wcm90bxIXVGFuZ28u",
+ "UE1SLlRocmVhZExvYWRpbmciHwodQ29udGludWVUaHJlYWRMb2FkaW5nUmVz",
+ "cG9uc2VCIwohY29tLnR3aW5lLnRhbmdvLnBtci50aHJlYWRsb2FkaW5nYgZw",
+ "cm90bzM="));
+ descriptor = pbr::FileDescriptor.FromGeneratedCode(descriptorData,
+ new pbr::FileDescriptor[] { },
+ new pbr::GeneratedClrTypeInfo(null, new pbr::GeneratedClrTypeInfo[] {
+ new pbr::GeneratedClrTypeInfo(typeof(global::Tango.PMR.ThreadLoading.ContinueThreadLoadingResponse), global::Tango.PMR.ThreadLoading.ContinueThreadLoadingResponse.Parser, null, null, null, null)
+ }));
+ }
+ #endregion
+
+ }
+ #region Messages
+ public sealed partial class ContinueThreadLoadingResponse : pb::IMessage<ContinueThreadLoadingResponse> {
+ private static readonly pb::MessageParser<ContinueThreadLoadingResponse> _parser = new pb::MessageParser<ContinueThreadLoadingResponse>(() => new ContinueThreadLoadingResponse());
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public static pb::MessageParser<ContinueThreadLoadingResponse> Parser { get { return _parser; } }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public static pbr::MessageDescriptor Descriptor {
+ get { return global::Tango.PMR.ThreadLoading.ContinueThreadLoadingResponseReflection.Descriptor.MessageTypes[0]; }
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ pbr::MessageDescriptor pb::IMessage.Descriptor {
+ get { return Descriptor; }
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public ContinueThreadLoadingResponse() {
+ OnConstruction();
+ }
+
+ partial void OnConstruction();
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public ContinueThreadLoadingResponse(ContinueThreadLoadingResponse other) : this() {
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public ContinueThreadLoadingResponse Clone() {
+ return new ContinueThreadLoadingResponse(this);
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public override bool Equals(object other) {
+ return Equals(other as ContinueThreadLoadingResponse);
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public bool Equals(ContinueThreadLoadingResponse other) {
+ if (ReferenceEquals(other, null)) {
+ return false;
+ }
+ if (ReferenceEquals(other, this)) {
+ return true;
+ }
+ return true;
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public override int GetHashCode() {
+ int hash = 1;
+ return hash;
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public override string ToString() {
+ return pb::JsonFormatter.ToDiagnosticString(this);
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public void WriteTo(pb::CodedOutputStream output) {
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public int CalculateSize() {
+ int size = 0;
+ return size;
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public void MergeFrom(ContinueThreadLoadingResponse other) {
+ if (other == null) {
+ return;
+ }
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public void MergeFrom(pb::CodedInputStream input) {
+ uint tag;
+ while ((tag = input.ReadTag()) != 0) {
+ switch(tag) {
+ default:
+ input.SkipLastField();
+ break;
+ }
+ }
+ }
+
+ }
+
+ #endregion
+
+}
+
+#endregion Designer generated code
diff --git a/Software/Visual_Studio/Tango.PMR/ThreadLoading/StartThreadLoadingResponse.cs b/Software/Visual_Studio/Tango.PMR/ThreadLoading/StartThreadLoadingResponse.cs
new file mode 100644
index 000000000..2f4fe40b0
--- /dev/null
+++ b/Software/Visual_Studio/Tango.PMR/ThreadLoading/StartThreadLoadingResponse.cs
@@ -0,0 +1,190 @@
+// Generated by the protocol buffer compiler. DO NOT EDIT!
+// source: StartThreadLoadingResponse.proto
+#pragma warning disable 1591, 0612, 3021
+#region Designer generated code
+
+using pb = global::Google.Protobuf;
+using pbc = global::Google.Protobuf.Collections;
+using pbr = global::Google.Protobuf.Reflection;
+using scg = global::System.Collections.Generic;
+namespace Tango.PMR.ThreadLoading {
+
+ /// <summary>Holder for reflection information generated from StartThreadLoadingResponse.proto</summary>
+ public static partial class StartThreadLoadingResponseReflection {
+
+ #region Descriptor
+ /// <summary>File descriptor for StartThreadLoadingResponse.proto</summary>
+ public static pbr::FileDescriptor Descriptor {
+ get { return descriptor; }
+ }
+ private static pbr::FileDescriptor descriptor;
+
+ static StartThreadLoadingResponseReflection() {
+ byte[] descriptorData = global::System.Convert.FromBase64String(
+ string.Concat(
+ "CiBTdGFydFRocmVhZExvYWRpbmdSZXNwb25zZS5wcm90bxIXVGFuZ28uUE1S",
+ "LlRocmVhZExvYWRpbmcaGFRocmVhZExvYWRpbmdTdGF0ZS5wcm90byJtChpT",
+ "dGFydFRocmVhZExvYWRpbmdSZXNwb25zZRI6CgVTdGF0ZRgBIAEoDjIrLlRh",
+ "bmdvLlBNUi5UaHJlYWRMb2FkaW5nLlRocmVhZExvYWRpbmdTdGF0ZRITCgtF",
+ "cnJvclJlYXNvbhgCIAEoCUIjCiFjb20udHdpbmUudGFuZ28ucG1yLnRocmVh",
+ "ZGxvYWRpbmdiBnByb3RvMw=="));
+ descriptor = pbr::FileDescriptor.FromGeneratedCode(descriptorData,
+ new pbr::FileDescriptor[] { global::Tango.PMR.ThreadLoading.ThreadLoadingStateReflection.Descriptor, },
+ new pbr::GeneratedClrTypeInfo(null, new pbr::GeneratedClrTypeInfo[] {
+ new pbr::GeneratedClrTypeInfo(typeof(global::Tango.PMR.ThreadLoading.StartThreadLoadingResponse), global::Tango.PMR.ThreadLoading.StartThreadLoadingResponse.Parser, new[]{ "State", "ErrorReason" }, null, null, null)
+ }));
+ }
+ #endregion
+
+ }
+ #region Messages
+ public sealed partial class StartThreadLoadingResponse : pb::IMessage<StartThreadLoadingResponse> {
+ private static readonly pb::MessageParser<StartThreadLoadingResponse> _parser = new pb::MessageParser<StartThreadLoadingResponse>(() => new StartThreadLoadingResponse());
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public static pb::MessageParser<StartThreadLoadingResponse> Parser { get { return _parser; } }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public static pbr::MessageDescriptor Descriptor {
+ get { return global::Tango.PMR.ThreadLoading.StartThreadLoadingResponseReflection.Descriptor.MessageTypes[0]; }
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ pbr::MessageDescriptor pb::IMessage.Descriptor {
+ get { return Descriptor; }
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public StartThreadLoadingResponse() {
+ OnConstruction();
+ }
+
+ partial void OnConstruction();
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public StartThreadLoadingResponse(StartThreadLoadingResponse other) : this() {
+ state_ = other.state_;
+ errorReason_ = other.errorReason_;
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public StartThreadLoadingResponse Clone() {
+ return new StartThreadLoadingResponse(this);
+ }
+
+ /// <summary>Field number for the "State" field.</summary>
+ public const int StateFieldNumber = 1;
+ private global::Tango.PMR.ThreadLoading.ThreadLoadingState state_ = 0;
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public global::Tango.PMR.ThreadLoading.ThreadLoadingState State {
+ get { return state_; }
+ set {
+ state_ = value;
+ }
+ }
+
+ /// <summary>Field number for the "ErrorReason" field.</summary>
+ public const int ErrorReasonFieldNumber = 2;
+ private string errorReason_ = "";
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public string ErrorReason {
+ get { return errorReason_; }
+ set {
+ errorReason_ = pb::ProtoPreconditions.CheckNotNull(value, "value");
+ }
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public override bool Equals(object other) {
+ return Equals(other as StartThreadLoadingResponse);
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public bool Equals(StartThreadLoadingResponse other) {
+ if (ReferenceEquals(other, null)) {
+ return false;
+ }
+ if (ReferenceEquals(other, this)) {
+ return true;
+ }
+ if (State != other.State) return false;
+ if (ErrorReason != other.ErrorReason) return false;
+ return true;
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public override int GetHashCode() {
+ int hash = 1;
+ if (State != 0) hash ^= State.GetHashCode();
+ if (ErrorReason.Length != 0) hash ^= ErrorReason.GetHashCode();
+ return hash;
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public override string ToString() {
+ return pb::JsonFormatter.ToDiagnosticString(this);
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public void WriteTo(pb::CodedOutputStream output) {
+ if (State != 0) {
+ output.WriteRawTag(8);
+ output.WriteEnum((int) State);
+ }
+ if (ErrorReason.Length != 0) {
+ output.WriteRawTag(18);
+ output.WriteString(ErrorReason);
+ }
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public int CalculateSize() {
+ int size = 0;
+ if (State != 0) {
+ size += 1 + pb::CodedOutputStream.ComputeEnumSize((int) State);
+ }
+ if (ErrorReason.Length != 0) {
+ size += 1 + pb::CodedOutputStream.ComputeStringSize(ErrorReason);
+ }
+ return size;
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public void MergeFrom(StartThreadLoadingResponse other) {
+ if (other == null) {
+ return;
+ }
+ if (other.State != 0) {
+ State = other.State;
+ }
+ if (other.ErrorReason.Length != 0) {
+ ErrorReason = other.ErrorReason;
+ }
+ }
+
+ [global::System.Diagnostics.DebuggerNonUserCodeAttribute]
+ public void MergeFrom(pb::CodedInputStream input) {
+ uint tag;
+ while ((tag = input.ReadTag()) != 0) {
+ switch(tag) {
+ default:
+ input.SkipLastField();
+ break;
+ case 8: {
+ state_ = (global::Tango.PMR.ThreadLoading.ThreadLoadingState) input.ReadEnum();
+ break;
+ }
+ case 18: {
+ ErrorReason = input.ReadString();
+ break;
+ }
+ }
+ }
+ }
+
+ }
+
+ #endregion
+
+}
+
+#endregion Designer generated code
diff --git a/Software/Visual_Studio/Tango.PMR/ThreadLoading/ThreadLoadingState.cs b/Software/Visual_Studio/Tango.PMR/ThreadLoading/ThreadLoadingState.cs
new file mode 100644
index 000000000..5eca15290
--- /dev/null
+++ b/Software/Visual_Studio/Tango.PMR/ThreadLoading/ThreadLoadingState.cs
@@ -0,0 +1,53 @@
+// Generated by the protocol buffer compiler. DO NOT EDIT!
+// source: ThreadLoadingState.proto
+#pragma warning disable 1591, 0612, 3021
+#region Designer generated code
+
+using pb = global::Google.Protobuf;
+using pbc = global::Google.Protobuf.Collections;
+using pbr = global::Google.Protobuf.Reflection;
+using scg = global::System.Collections.Generic;
+namespace Tango.PMR.ThreadLoading {
+
+ /// <summary>Holder for reflection information generated from ThreadLoadingState.proto</summary>
+ public static partial class ThreadLoadingStateReflection {
+
+ #region Descriptor
+ /// <summary>File descriptor for ThreadLoadingState.proto</summary>
+ public static pbr::FileDescriptor Descriptor {
+ get { return descriptor; }
+ }
+ private static pbr::FileDescriptor descriptor;
+
+ static ThreadLoadingStateReflection() {
+ byte[] descriptorData = global::System.Convert.FromBase64String(
+ string.Concat(
+ "ChhUaHJlYWRMb2FkaW5nU3RhdGUucHJvdG8SF1RhbmdvLlBNUi5UaHJlYWRM",
+ "b2FkaW5nKo4BChJUaHJlYWRMb2FkaW5nU3RhdGUSCAoETm9uZRAAEg0KCVBy",
+ "ZXBhcmluZxABEhMKD1JlYWR5Rm9yTG9hZGluZxACEhQKEFByZXBhcmF0aW9u",
+ "RXJyb3IQAxIOCgpGaW5hbGl6aW5nEAQSFQoRRmluYWxpemF0aW9uRXJyb3IQ",
+ "BRINCglDb21wbGV0ZWQQBkIjCiFjb20udHdpbmUudGFuZ28ucG1yLnRocmVh",
+ "ZGxvYWRpbmdiBnByb3RvMw=="));
+ descriptor = pbr::FileDescriptor.FromGeneratedCode(descriptorData,
+ new pbr::FileDescriptor[] { },
+ new pbr::GeneratedClrTypeInfo(new[] {typeof(global::Tango.PMR.ThreadLoading.ThreadLoadingState), }, null));
+ }
+ #endregion
+
+ }
+ #region Enums
+ public enum ThreadLoadingState {
+ [pbr::OriginalName("None")] None = 0,
+ [pbr::OriginalName("Preparing")] Preparing = 1,
+ [pbr::OriginalName("ReadyForLoading")] ReadyForLoading = 2,
+ [pbr::OriginalName("PreparationError")] PreparationError = 3,
+ [pbr::OriginalName("Finalizing")] Finalizing = 4,
+ [pbr::OriginalName("FinalizationError")] FinalizationError = 5,
+ [pbr::OriginalName("Completed")] Completed = 6,
+ }
+
+ #endregion
+
+}
+
+#endregion Designer generated code
diff --git a/Software/Visual_Studio/Tango.PMR/Diagnostics/StartThreadLoadingUpdateRequest.cs b/Software/Visual_Studio/Tango.PMR/ThreadLoading/StartThreadLoadingRequest.cs
index a466722ad..f5116e315 100644
--- a/Software/Visual_Studio/Tango.PMR/Diagnostics/StartThreadLoadingUpdateRequest.cs
+++ b/Software/Visual_Studio/Tango.PMR/ThreadLoading/StartThreadLoadingRequest.cs
@@ -1,5 +1,5 @@
// Generated by the protocol buffer compiler. DO NOT EDIT!
-// source: StartThreadLoadingUpdateRequest.proto
+// source: StartThreadLoadingRequest.proto
#pragma warning disable 1591, 0612, 3021
#region Designer generated code
@@ -7,43 +7,42 @@ using pb = global::Google.Protobuf;
using pbc = global::Google.Protobuf.Collections;
using pbr = global::Google.Protobuf.Reflection;
using scg = global::System.Collections.Generic;
-namespace Tango.PMR.Diagnostics {
+namespace Tango.PMR.ThreadLoading {
- /// <summary>Holder for reflection information generated from StartThreadLoadingUpdateRequest.proto</summary>
- public static partial class StartThreadLoadingUpdateRequestReflection {
+ /// <summary>Holder for reflection information generated from StartThreadLoadingRequest.proto</summary>
+ public static partial class StartThreadLoadingRequestReflection {
#region Descriptor
/// <summary>File descriptor for StartThreadLoadingUpdateRequest.proto</summary>
public static pbr::FileDescriptor Descriptor {
get { return descriptor; }
}
private static pbr::FileDescriptor descriptor;
- static StartThreadLoadingUpdateRequestReflection() {
+ static StartThreadLoadingRequestReflection() {
byte[] descriptorData = global::System.Convert.FromBase64String(
string.Concat(
- "CiVTdGFydFRocmVhZExvYWRpbmdVcGRhdGVSZXF1ZXN0LnByb3RvEhVUYW5n",
- "by5QTVIuRGlhZ25vc3RpY3MiIQofU3RhcnRUaHJlYWRMb2FkaW5nVXBkYXRl",
- "UmVxdWVzdEIhCh9jb20udHdpbmUudGFuZ28ucG1yLmRpYWdub3N0aWNzYgZw",
- "cm90bzM="));
+ "Ch9TdGFydFRocmVhZExvYWRpbmdSZXF1ZXN0LnByb3RvEhdUYW5nby5QTVIu",
+ "VGhyZWFkTG9hZGluZyIbChlTdGFydFRocmVhZExvYWRpbmdSZXF1ZXN0QiMK",
+ "IWNvbS50d2luZS50YW5nby5wbXIudGhyZWFkbG9hZGluZ2IGcHJvdG8z"));
descriptor = pbr::FileDescriptor.FromGeneratedCode(descriptorData,
new pbr::FileDescriptor[] { },
new pbr::GeneratedClrTypeInfo(null, new pbr::GeneratedClrTypeInfo[] {
- new pbr::GeneratedClrTypeInfo(typeof(global::Tango.PMR.Diagnostics.StartThreadLoadingUpdateRequest), global::Tango.PMR.Diagnostics.StartThreadLoadingUpdateRequest.Parser, null, null, null, null)
+ new pbr::GeneratedClrTypeInfo(typeof(global::Tango.PMR.ThreadLoading.StartThreadLoadingRequest), global::Tango.PMR.ThreadLoading.StartThreadLoadingRequest.Parser, null, null, null, null)
}));
}
#endregion
}
#region Messages
- public sealed partial class StartThreadLoadingUpdateRequest : pb::IMessage<StartThreadLoadingUpdateRequest> {
- private static readonly pb::MessageParser<StartThreadLoadingUpdateRequest> _parser = new pb::MessageParser<StartThreadLoadingUpdateRequest>(() => new StartThreadLoadingUpdateRequest());
+ public sealed partial class StartThreadLoadingRequest : pb::IMessage<StartThreadLoadingRequest> {
+ private static readonly pb::MessageParser<StartThreadLoadingRequest> _parser = new pb::MessageParser<StartThreadLoadingRequest>(() => new StartThreadLoadingRequest());
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
- public static pb::MessageParser<StartThreadLoadingUpdateRequest> Parser { get { return _parser; } }
+ public static pb::MessageParser<StartThreadLoadingRequest> Parser { get { return _parser; } }
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
public static pbr::MessageDescriptor Descriptor {
- get { return global::Tango.PMR.Diagnostics.StartThreadLoadingUpdateRequestReflection.Descriptor.MessageTypes[0]; }
+ get { return global::Tango.PMR.ThreadLoading.StartThreadLoadingRequestReflection.Descriptor.MessageTypes[0]; }
}
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
@@ -52,28 +51,28 @@ namespace Tango.PMR.Diagnostics {
}
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
- public StartThreadLoadingUpdateRequest() {
+ public StartThreadLoadingRequest() {
OnConstruction();
}
partial void OnConstruction();
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
- public StartThreadLoadingUpdateRequest(StartThreadLoadingUpdateRequest other) : this() {
+ public StartThreadLoadingRequest(StartThreadLoadingRequest other) : this() {
}
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
- public StartThreadLoadingUpdateRequest Clone() {
- return new StartThreadLoadingUpdateRequest(this);
+ public StartThreadLoadingRequest Clone() {
+ return new StartThreadLoadingRequest(this);
}
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
public override bool Equals(object other) {
- return Equals(other as StartThreadLoadingUpdateRequest);
+ return Equals(other as StartThreadLoadingRequest);
}
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
- public bool Equals(StartThreadLoadingUpdateRequest other) {
+ public bool Equals(StartThreadLoadingRequest other) {
if (ReferenceEquals(other, null)) {
return false;
}
@@ -105,7 +104,7 @@ namespace Tango.PMR.Diagnostics {
}
[global::System.Diagnostics.DebuggerNonUserCodeAttribute]
- public void MergeFrom(StartThreadLoadingUpdateRequest other) {
+ public void MergeFrom(StartThreadLoadingRequest other) {
if (other == null) {
return;
}
@@ -7,43 +7,42 @@ using pb = global::Google.Protobuf;
#region Descriptor
- /// <summary>File descriptor for StartThreadLoadingUpdateRequest.proto</summary>
+ /// <summary>File descriptor for StartThreadLoadingRequest.proto</summary>
public static pbr::FileDescriptor Descriptor {
get { return descriptor; }